@@ -1,6 +1,6 @@
 package App::duino::Command::com;
 {
-  $App::duino::Command::com::VERSION = '0.08';
+  $App::duino::Command::com::VERSION = '0.10';
 }
 
 use strict;
@@ -9,6 +9,7 @@ use warnings;
 use App::duino -command;
 
 use Device::SerialPort;
+use IPC::Cmd qw(can_run);
 
 =head1 NAME
 
@@ -16,12 +17,19 @@ App::duino::Command::com - Open a serial monitor to an Arduino
 
 =head1 VERSION
 
-version 0.08
+version 0.10
 
 =head1 SYNOPSIS
 
   $ duino com --port /dev/ttyACM0
 
+=head1 DESCRIPTION
+
+This command can be used to initiate a serial monitor with an Arduino board (or
+any other device that supports serial communication). The C<picocom> terminal
+emulator will be used if installed, otherwise a built-in RX-only terminal will
+be started.
+
 =cut
 
 sub abstract { 'open a serial monitor to an Arduino' }
@@ -40,18 +48,34 @@ sub opt_spec {
 sub execute {
 	my ($self, $opt, $args) = @_;
 
-	open my $fh, '<', $opt -> port
-		or die "Can't open serial port '" . $opt -> port . "'.\n";
+	if (can_run('picocom')) {
+		system 'picocom', $opt -> port;
+	} else {
+		open my $fh, '<', $opt -> port
+			or die "Can't open serial port '".$opt -> port."'.\n";
 
-	my $fd = fileno $fh;
+		my $fd = fileno $fh;
 
-	while (read $fh, my $char, 1) {
-		print $char;
+		while (read $fh, my $char, 1) {
+			print $char;
+		}
+
+		close $fh;
 	}
-
-	close $fh;
 }
 
+=head1 OPTIONS
+
+=over 4
+
+=item B<--port>, B<-p>
+
+The path to the Arduino serial port. The environment variable C<ARDUINO_PORT>
+will be used if present and if the command-line option is not set. If neither
+of them is set the default value (C</dev/ttyACM0>) will be used.
+
+=back
+
 =head1 AUTHOR
 
 Alessandro Ghedini <alexbio@cpan.org>
